==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/WsfcDomainProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs.builder
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.ClusterSubnetType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Active Directory account details to operate Windows Server Failover Cluster.
 * @property clusterBootstrapAccount Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
 * @property clusterOperatorAccount Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
 * @property clusterSubnetType Cluster subnet type.
 * @property domainFqdn Fully qualified name of the domain.
 * @property fileShareWitnessPath Optional path for fileshare witness.
 * @property ouPath Organizational Unit path in which the nodes and cluster will be present.
 * @property sqlServiceAccount Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
 * @property storageAccountPrimaryKey Primary key of the witness storage account.
 * @property storageAccountUrl Fully qualified ARM resource id of the witness storage account.
 */
public data class WsfcDomainProfileArgs(
    public val clusterBootstrapAccount: Output<String>? = null,
    public val clusterOperatorAccount: Output<String>? = null,
    public val clusterSubnetType: Output<Either<String, ClusterSubnetType>>? = null,
    public val domainFqdn: Output<String>? = null,
    public val fileShareWitnessPath: Output<String>? = null,
    public val ouPath: Output<String>? = null,
    public val sqlServiceAccount: Output<String>? = null,
    public val storageAccountPrimaryKey: Output<String>? = null,
    public val storageAccountUrl: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs.builder()
            .clusterBootstrapAccount(clusterBootstrapAccount?.applyValue({ args0 -> args0 }))
            .clusterOperatorAccount(clusterOperatorAccount?.applyValue({ args0 -> args0 }))
            .clusterSubnetType(
                clusterSubnetType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .domainFqdn(domainFqdn?.applyValue({ args0 -> args0 }))
            .fileShareWitnessPath(fileShareWitnessPath?.applyValue({ args0 -> args0 }))
            .ouPath(ouPath?.applyValue({ args0 -> args0 }))
            .sqlServiceAccount(sqlServiceAccount?.applyValue({ args0 -> args0 }))
            .storageAccountPrimaryKey(storageAccountPrimaryKey?.applyValue({ args0 -> args0 }))
            .storageAccountUrl(storageAccountUrl?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WsfcDomainProfileArgs].
 */
@PulumiTagMarker
public class WsfcDomainProfileArgsBuilder internal constructor() {
    private var clusterBootstrapAccount: Output<String>? = null

    private var clusterOperatorAccount: Output<String>? = null

    private var clusterSubnetType: Output<Either<String, ClusterSubnetType>>? = null

    private var domainFqdn: Output<String>? = null

    private var fileShareWitnessPath: Output<String>? = null

    private var ouPath: Output<String>? = null

    private var sqlServiceAccount: Output<String>? = null

    private var storageAccountPrimaryKey: Output<String>? = null

    private var storageAccountUrl: Output<String>? = null

    /**
     * @param value Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
     */
    @JvmName("aldexisprvvsjnhe")
    public suspend fun clusterBootstrapAccount(`value`: Output<String>) {
        this.clusterBootstrapAccount = value
    }

    /**
     * @param value Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
     */
    @JvmName("dewmrsshacjxytsw")
    public suspend fun clusterOperatorAccount(`value`: Output<String>) {
        this.clusterOperatorAccount = value
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("hrcmxcerphbrrutj")
    public suspend fun clusterSubnetType(`value`: Output<Either<String, ClusterSubnetType>>) {
        this.clusterSubnetType = value
    }

    /**
     * @param value Fully qualified name of the domain.
     */
    @JvmName("xkgyrjojwognxswq")
    public suspend fun domainFqdn(`value`: Output<String>) {
        this.domainFqdn = value
    }

    /**
     * @param value Optional path for fileshare witness.
     */
    @JvmName("nnaxnqccommkoauq")
    public suspend fun fileShareWitnessPath(`value`: Output<String>) {
        this.fileShareWitnessPath = value
    }

    /**
     * @param value Organizational Unit path in which the nodes and cluster will be present.
     */
    @JvmName("haalrteswjunhidw")
    public suspend fun ouPath(`value`: Output<String>) {
        this.ouPath = value
    }

    /**
     * @param value Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
     */
    @JvmName("dbkavurxcrlapnqk")
    public suspend fun sqlServiceAccount(`value`: Output<String>) {
        this.sqlServiceAccount = value
    }

    /**
     * @param value Primary key of the witness storage account.
     */
    @JvmName("etfjfrhgpeivvcaa")
    public suspend fun storageAccountPrimaryKey(`value`: Output<String>) {
        this.storageAccountPrimaryKey = value
    }

    /**
     * @param value Fully qualified ARM resource id of the witness storage account.
     */
    @JvmName("wlephbytonopkhmj")
    public suspend fun storageAccountUrl(`value`: Output<String>) {
        this.storageAccountUrl = value
    }

    /**
     * @param value Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
     */
    @JvmName("yyimyxcrewkwdpmq")
    public suspend fun clusterBootstrapAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterBootstrapAccount = mapped
    }

    /**
     * @param value Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
     */
    @JvmName("gxkofiwhibaxtwud")
    public suspend fun clusterOperatorAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterOperatorAccount = mapped
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("ukpecdfkqnqgjvvc")
    public suspend fun clusterSubnetType(`value`: Either<String, ClusterSubnetType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterSubnetType = mapped
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("bqkbbgwypauimlxa")
    public fun clusterSubnetType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClusterSubnetType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterSubnetType = mapped
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("hcjgxyrkkqcycxnk")
    public fun clusterSubnetType(`value`: ClusterSubnetType) {
        val toBeMapped = Either.ofRight<String, ClusterSubnetType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterSubnetType = mapped
    }

    /**
     * @param value Fully qualified name of the domain.
     */
    @JvmName("wfsmxwymukgdyvkq")
    public suspend fun domainFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainFqdn = mapped
    }

    /**
     * @param value Optional path for fileshare witness.
     */
    @JvmName("csqrryjqfdjpufhp")
    public suspend fun fileShareWitnessPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileShareWitnessPath = mapped
    }

    /**
     * @param value Organizational Unit path in which the nodes and cluster will be present.
     */
    @JvmName("qihwqlviusdycdbc")
    public suspend fun ouPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ouPath = mapped
    }

    /**
     * @param value Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
     */
    @JvmName("negkadrokuwcbxyj")
    public suspend fun sqlServiceAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlServiceAccount = mapped
    }

    /**
     * @param value Primary key of the witness storage account.
     */
    @JvmName("pjewyrtdohxrafds")
    public suspend fun storageAccountPrimaryKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountPrimaryKey = mapped
    }

    /**
     * @param value Fully qualified ARM resource id of the witness storage account.
     */
    @JvmName("vtrialcfeaxwagls")
    public suspend fun storageAccountUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountUrl = mapped
    }

    internal fun build(): WsfcDomainProfileArgs = WsfcDomainProfileArgs(
        clusterBootstrapAccount = clusterBootstrapAccount,
        clusterOperatorAccount = clusterOperatorAccount,
        clusterSubnetType = clusterSubnetType,
        domainFqdn = domainFqdn,
        fileShareWitnessPath = fileShareWitnessPath,
        ouPath = ouPath,
        sqlServiceAccount = sqlServiceAccount,
        storageAccountPrimaryKey = storageAccountPrimaryKey,
        storageAccountUrl = storageAccountUrl,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/WsfcDomainProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs.builder
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.ClusterSubnetType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Active Directory account details to operate Windows Server Failover Cluster.
 * @property clusterBootstrapAccount Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
 * @property clusterOperatorAccount Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
 * @property clusterSubnetType Cluster subnet type.
 * @property domainFqdn Fully qualified name of the domain.
 * @property fileShareWitnessPath Optional path for fileshare witness.
 * @property ouPath Organizational Unit path in which the nodes and cluster will be present.
 * @property sqlServiceAccount Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
 * @property storageAccountPrimaryKey Primary key of the witness storage account.
 * @property storageAccountUrl Fully qualified ARM resource id of the witness storage account.
 */
public data class WsfcDomainProfileArgs(
    public val clusterBootstrapAccount: Output<String>? = null,
    public val clusterOperatorAccount: Output<String>? = null,
    public val clusterSubnetType: Output<Either<String, ClusterSubnetType>>? = null,
    public val domainFqdn: Output<String>? = null,
    public val fileShareWitnessPath: Output<String>? = null,
    public val ouPath: Output<String>? = null,
    public val sqlServiceAccount: Output<String>? = null,
    public val storageAccountPrimaryKey: Output<String>? = null,
    public val storageAccountUrl: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainProfileArgs.builder()
            .clusterBootstrapAccount(clusterBootstrapAccount?.applyValue({ args0 -> args0 }))
            .clusterOperatorAccount(clusterOperatorAccount?.applyValue({ args0 -> args0 }))
            .clusterSubnetType(
                clusterSubnetType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .domainFqdn(domainFqdn?.applyValue({ args0 -> args0 }))
            .fileShareWitnessPath(fileShareWitnessPath?.applyValue({ args0 -> args0 }))
            .ouPath(ouPath?.applyValue({ args0 -> args0 }))
            .sqlServiceAccount(sqlServiceAccount?.applyValue({ args0 -> args0 }))
            .storageAccountPrimaryKey(storageAccountPrimaryKey?.applyValue({ args0 -> args0 }))
            .storageAccountUrl(storageAccountUrl?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WsfcDomainProfileArgs].
 */
@PulumiTagMarker
public class WsfcDomainProfileArgsBuilder internal constructor() {
    private var clusterBootstrapAccount: Output<String>? = null

    private var clusterOperatorAccount: Output<String>? = null

    private var clusterSubnetType: Output<Either<String, ClusterSubnetType>>? = null

    private var domainFqdn: Output<String>? = null

    private var fileShareWitnessPath: Output<String>? = null

    private var ouPath: Output<String>? = null

    private var sqlServiceAccount: Output<String>? = null

    private var storageAccountPrimaryKey: Output<String>? = null

    private var storageAccountUrl: Output<String>? = null

    /**
     * @param value Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
     */
    @JvmName("dlyglebnsvarglue")
    public suspend fun clusterBootstrapAccount(`value`: Output<String>) {
        this.clusterBootstrapAccount = value
    }

    /**
     * @param value Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
     */
    @JvmName("uwcmxxtdrupdxxfj")
    public suspend fun clusterOperatorAccount(`value`: Output<String>) {
        this.clusterOperatorAccount = value
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("tupwvvbmxinuxpil")
    public suspend fun clusterSubnetType(`value`: Output<Either<String, ClusterSubnetType>>) {
        this.clusterSubnetType = value
    }

    /**
     * @param value Fully qualified name of the domain.
     */
    @JvmName("vhislnlcuroatcev")
    public suspend fun domainFqdn(`value`: Output<String>) {
        this.domainFqdn = value
    }

    /**
     * @param value Optional path for fileshare witness.
     */
    @JvmName("fgbuqnvdgnvamfgu")
    public suspend fun fileShareWitnessPath(`value`: Output<String>) {
        this.fileShareWitnessPath = value
    }

    /**
     * @param value Organizational Unit path in which the nodes and cluster will be present.
     */
    @JvmName("lkogxmsvuswwrcvh")
    public suspend fun ouPath(`value`: Output<String>) {
        this.ouPath = value
    }

    /**
     * @param value Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
     */
    @JvmName("idotncjsxgxqbyif")
    public suspend fun sqlServiceAccount(`value`: Output<String>) {
        this.sqlServiceAccount = value
    }

    /**
     * @param value Primary key of the witness storage account.
     */
    @JvmName("hgpiorccoolvrsdk")
    public suspend fun storageAccountPrimaryKey(`value`: Output<String>) {
        this.storageAccountPrimaryKey = value
    }

    /**
     * @param value Fully qualified ARM resource id of the witness storage account.
     */
    @JvmName("jcclvhjumncmpelh")
    public suspend fun storageAccountUrl(`value`: Output<String>) {
        this.storageAccountUrl = value
    }

    /**
     * @param value Account name used for creating cluster (at minimum needs permissions to 'Create Computer Objects' in domain).
     */
    @JvmName("neucdkgicovsddak")
    public suspend fun clusterBootstrapAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterBootstrapAccount = mapped
    }

    /**
     * @param value Account name used for operating cluster i.e. will be part of administrators group on all the participating virtual machines in the cluster.
     */
    @JvmName("nrurtyvemkpmjbhx")
    public suspend fun clusterOperatorAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterOperatorAccount = mapped
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("cckodmxhtonrmhmb")
    public suspend fun clusterSubnetType(`value`: Either<String, ClusterSubnetType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterSubnetType = mapped
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("badimlhegiwmurnh")
    public fun clusterSubnetType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ClusterSubnetType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterSubnetType = mapped
    }

    /**
     * @param value Cluster subnet type.
     */
    @JvmName("lsjotiismxjrhbru")
    public fun clusterSubnetType(`value`: ClusterSubnetType) {
        val toBeMapped = Either.ofRight<String, ClusterSubnetType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clusterSubnetType = mapped
    }

    /**
     * @param value Fully qualified name of the domain.
     */
    @JvmName("aypwqmsmaxrknybq")
    public suspend fun domainFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainFqdn = mapped
    }

    /**
     * @param value Optional path for fileshare witness.
     */
    @JvmName("mxnjpdmcouubpdlx")
    public suspend fun fileShareWitnessPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileShareWitnessPath = mapped
    }

    /**
     * @param value Organizational Unit path in which the nodes and cluster will be present.
     */
    @JvmName("mboxjxrklmbvvufu")
    public suspend fun ouPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ouPath = mapped
    }

    /**
     * @param value Account name under which SQL service will run on all participating SQL virtual machines in the cluster.
     */
    @JvmName("fsbdcygcplpwaatu")
    public suspend fun sqlServiceAccount(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlServiceAccount = mapped
    }

    /**
     * @param value Primary key of the witness storage account.
     */
    @JvmName("gmfqghqbqeleyrks")
    public suspend fun storageAccountPrimaryKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountPrimaryKey = mapped
    }

    /**
     * @param value Fully qualified ARM resource id of the witness storage account.
     */
    @JvmName("gfxnncnpkqbbpwtg")
    public suspend fun storageAccountUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountUrl = mapped
    }

    internal fun build(): WsfcDomainProfileArgs = WsfcDomainProfileArgs(
        clusterBootstrapAccount = clusterBootstrapAccount,
        clusterOperatorAccount = clusterOperatorAccount,
        clusterSubnetType = clusterSubnetType,
        domainFqdn = domainFqdn,
        fileShareWitnessPath = fileShareWitnessPath,
        ouPath = ouPath,
        sqlServiceAccount = sqlServiceAccount,
        storageAccountPrimaryKey = storageAccountPrimaryKey,
        storageAccountUrl = storageAccountUrl,
    )
}
